@@ -10,13 +10,13 @@ use clap::Parser;
 
 use promkit::{
     crossterm::style::{Attribute, Attributes, Color},
-    json, listbox,
+    listbox,
     style::StyleBuilder,
     text, text_editor,
 };
 
 mod jnv;
-use jnv::Jnv;
+use jnv::{Jnv, JsonTheme};
 mod trie;
 
 /// JSON navigator and interactive filter leveraging jq
@@ -99,6 +99,18 @@ pub struct Args {
     )]
     pub json_expand_depth: Option<usize>,
 
+    #[arg(
+        short = 's',
+        long = "limit-length",
+        default_value = "50",
+        help = "Limit length of JSON array in the visualization.",
+        long_help = "
+        Specifies the limit length to load JSON array in the visualization.
+        Note: Increasing this length can significantly slow down the display for large datasets.
+        "
+    )]
+    pub json_limit_length: Option<usize>,
+
     #[arg(
         short = 'l',
         long = "suggestion-list-length",
@@ -175,15 +187,17 @@ fn main() -> Result<()> {
     let suggestions = listbox::State {
         listbox: listbox::Listbox::from_iter(Vec::<String>::new()),
         cursor: String::from("❯ "),
-        active_item_style: StyleBuilder::new()
-            .fgc(Color::Grey)
-            .bgc(Color::Yellow)
-            .build(),
-        inactive_item_style: StyleBuilder::new().fgc(Color::Grey).build(),
+        active_item_style: Some(
+            StyleBuilder::new()
+                .fgc(Color::Grey)
+                .bgc(Color::Yellow)
+                .build(),
+        ),
+        inactive_item_style: Some(StyleBuilder::new().fgc(Color::Grey).build()),
         lines: Some(args.suggestion_list_length),
     };
 
-    let json_theme = json::Theme {
+    let json_theme = JsonTheme {
         curly_brackets_style: StyleBuilder::new()
             .attrs(Attributes::from(Attribute::Bold))
             .build(),
@@ -208,6 +222,7 @@ fn main() -> Result<()> {
         suggestions,
         json_theme,
         args.json_expand_depth,
+        args.json_limit_length,
         args.no_hint,
     )?;
     let _ = prompt.run()?;
